AgendaStyle class

Sets the style to customize SfCalendar month agenda view.

Allows to customize the backgroundColor, dayTextStyle, dateTextStyle and appointmentTextStyle in month agenda view of calendar.

See also:

Widget build(BuildContext context) {
return Container(
   child: SfCalendar(
     view: CalendarView.month,
     monthViewSettings: MonthViewSettings(
         dayFormat: 'EEE',
         numberOfWeeksInView: 4,
         appointmentDisplayCount: 2,
         appointmentDisplayMode: MonthAppointmentDisplayMode.appointment,
         showAgenda: true,
         navigationDirection: MonthNavigationDirection.horizontal,
         agendaStyle: AgendaStyle(
             backgroundColor: Colors.transparent,
            appointmentTextStyle: TextStyle(
                 color: Colors.white,
                 fontSize: 13,
                 fontStyle: FontStyle.italic
             ),
             dayTextStyle: TextStyle(color: Colors.red,
                 fontSize: 13,
                 fontStyle: FontStyle.italic),
             dateTextStyle: TextStyle(color: Colors.red,
                 fontSize: 25,
                 fontWeight: FontWeight.bold,
                 fontStyle: FontStyle.normal)
        )),
     ),
   );
}
Mixed-in types
Annotations

Constructors

AgendaStyle({TextStyle? appointmentTextStyle, TextStyle? dayTextStyle, TextStyle? dateTextStyle, Color? backgroundColor, TextStyle placeholderTextStyle = const TextStyle(color: Colors.grey, fontSize: 15)})
Creates a agenda style for month view in calendar.
const

Properties

appointmentTextStyle → TextStyle?
The text style for the text in the Appointment view in SfCalendar month agenda view.
final
backgroundColor → Color?
The background color to fill the background of the SfCalendar month agenda view.
final
dateTextStyle → TextStyle?
The text style for the text in the date view of SfCalendar month agenda view.
final
dayTextStyle → TextStyle?
The text style for the text in the day text of SfCalendar month agenda view.
final
hashCode → int
The hash code for this object.
no setteroverride
placeholderTextStyle → TextStyle
The text style for the text in the placeholder (no event text and no selected date text) of the SfCalendar month agenda view.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override