AppointmentDragUpdateDetails class

The appointment that dragging on view in SfCalendar

Details for AppointmentDragUpdateCallback, such as appointment, sourceResource, targetResource, draggingPosition and draggingTime.

See also:

Annotations

Constructors

AppointmentDragUpdateDetails(Object? appointment, CalendarResource? sourceResource, CalendarResource? targetResource, Offset? draggingPosition, DateTime? draggingTime)
Creates details for AppointmentDragUpdateCallback.
const

Properties

appointment → Object?
The dragging appointment.
final
draggingPosition → Offset?
The current dragging position.
final
draggingTime → DateTime?
The current dragging time of the appointment.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceResource → CalendarResource?
The source resource of the dragging appointment.
final
targetResource → CalendarResource?
The resource in which the appointment dragging.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited