AppointmentResizeStartDetails class

The appointment that starts resizing on view in SfCalendar

Details for AppointmentResizeStartCallback, such as appointment, and resource

See also:

Constructors

AppointmentResizeStartDetails(dynamic appointment, CalendarResource? resource)
Creates details for AppointmentResizeStartCallback.
const

Properties

appointment → dynamic
The appointment that starts resizing on view in SfCalendar.
final
hashCode → int
The hash code for this object.
no setterinherited
resource → CalendarResource?
The resource associated with the resizing appointment in timeline views.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited