AppointmentResizeUpdateDetails class

The appointment that resizing on view in SfCalendar

Details for AppointmentResizeUpdateCallback, such as appointment, resizingTime, resizingOffset and resource.

See also:

Constructors

AppointmentResizeUpdateDetails(dynamic appointment, CalendarResource? resource, DateTime? resizingTime, Offset? resizingOffset)
Creates details for AppointmentResizeUpdateCallback.
const

Properties

appointment → dynamic
The appointment that resizing on view in SfCalendar.
final
hashCode → int
The hash code for this object.
no setterinherited
resizingOffset → Offset?
The current resize position of the appointment.
final
resizingTime → DateTime?
The current resizing time value of the appointment.
final
resource → CalendarResource?
The resource associated with the resizing appointment in timeline views.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited