AppointmentType enum

Available Appointment types for Appointment

Inheritance
Available extensions

Values

changedOccurrence → const AppointmentType
  • AppointmentType.changedOccurrence, this specifies the appointment is a changed occurrence from the recurrence series.
normal → const AppointmentType

AppointmentType.normal, this specifies a standard appointment.

occurrence → const AppointmentType
  • AppointmentType.occurrence, this specifies the appointment is an occurrence of pattern appointment which was created based on RRule of the pattern appointment.
pattern → const AppointmentType
  • AppointmentType.pattern, this specifies the pattern appointment which has the RRule value and it is the pattern for the occurrence appointment in the recurrence series.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<AppointmentType>
A constant List of the values in this enum, in order of their declaration.