CalendarDataSourceCallback typedef
CalendarDataSourceCallback =
void Function(CalendarDataSourceAction, List)
Signature for callback that reports that a appointment collection set to the CalendarDataSource modified.
See also: CalendarDataSourceAction, the actions which can be performed using the calendar.
Implementation
typedef CalendarDataSourceCallback = void Function(
CalendarDataSourceAction,
List<dynamic>,
);