CalendarDetails class

Inheritance
Annotations

Constructors

CalendarDetails(List? appointments, DateTime? date, CalendarElement element, CalendarResource? resource)
creates details for CalendarDetailsCallback.
const

Properties

appointments → List?
The collection of appointments that return from the date.
finalinherited
date → DateTime?
The date that return from the view.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
resource → CalendarResource?
The resource associated with the calendar cell in timeline views.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetElement → CalendarElement
The element that return from the view.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited