CalendarSelectionDetails class

The element that tapped on view in SfCalendar

Details for CalendarSelectionChangedCallback, such as date, and resource.

See also:

Annotations

Constructors

CalendarSelectionDetails(DateTime? date, CalendarResource? resource)
Creates details for CalendarSelectionChangedCallback.
const

Properties

date → DateTime?
The date time value that represents selected calendar cell on timeslot and month views.
final
hashCode → int
The hash code for this object.
no setterinherited
resource → CalendarResource?
The resource associated with the selected calendar cell in timeline views.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited