MonthCellDetails class

Contains the details that needed on month cell builder.

Details for the MonthCellBuilder, such as date, appointments, visibleDates and bounds.

See also:

Constructors

MonthCellDetails(DateTime date, List<Object> appointments, List<DateTime> visibleDates, Rect bounds)
Default constructor to store the details needed in month cell builder
const

Properties

appointments → List<Object>
The appointments associated with this date.
final
bounds → Rect
The position and size of the widget.
final
date → DateTime
The date value associated with the month cell widget.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visibleDates → List<DateTime>
The visible dates of the month view.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited