ResourceViewHeaderDetails class

Contains the details that needed on resource view header builder.

See also:

Constructors

ResourceViewHeaderDetails(CalendarResource resource, Rect bounds)
Default constructor to store the details needed in resource view header builder.

Properties

bounds → Rect
The position and size of the widget.
final
hashCode → int
The hash code for this object.
no setterinherited
resource → CalendarResource
The resource details such as display name, color, id and image associated with the resource header widget.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited