size property

  1. @Deprecated('Use the width property to control the resource panel width and the height property to control each resource item height.')
double size
final

Applies a uniform size to both the resource panel width and the height of each resource item.

If width or height is specified explicitly, those values take precedence over size.

Defaults to 75.

See also:

@override
 Widget build(BuildContext context) {
   return Container(
     child: SfCalendar(
       view: CalendarView.timelineMonth,
       dataSource: _getCalendarDataSource(),
       resourceViewSettings: ResourceViewSettings(
           visibleResourceCount: 4,
           size: 150,
           displayNameTextStyle: TextStyle(
               fontStyle: FontStyle.italic,
               fontSize: 15,
               fontWeight: FontWeight.w400)),
     ),
   );
 }
}

Implementation

@Deprecated(
  'Use the width property to control the resource panel width and the height property to control each resource item height.',
)
final double size;