ScheduleViewMonthHeaderDetails class

Contains the details that needed on schedule view month header builder.

See also:

Constructors

ScheduleViewMonthHeaderDetails(DateTime date, Rect bounds)
Default constructor to store the details needed in builder
const

Properties

bounds → Rect
The position and size of the widget.
final
date → DateTime
The date value associated with the schedule view month header widget.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited