TimeRegionDetails class

Contains the details that needed on special region view builder.

See also:

Constructors

TimeRegionDetails(TimeRegion region, DateTime date, Rect bounds)
Default constructor to store the details needed in time region builder.

Properties

bounds → Rect
Position and size of the time region view widget.
final
date → DateTime
Date value associated with the time region.
final
hashCode → int
The hash code for this object.
no setterinherited
region → TimeRegion
Region detail associated with the time region view in day, week, workweek and timeline day, week, workweek views.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited