ViewNavigationMode enum

Available view navigation modes for SfCalendar.

See also:

Inheritance
Available extensions

Values

snap → const ViewNavigationMode
  • ViewNavigationMode.snap, allows to switching to previous/next views through swipe interaction in SfCalendar.
none → const ViewNavigationMode
  • ViewNavigationMode.none, restrict the next or previous view dates to be shown by swipe interaction in SfCalendar.

It will not impact scrolling timeslot views, controller.forward, controller.backward and showNavigationArrow.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ViewNavigationMode>
A constant List of the values in this enum, in order of their declaration.