WeekNumberStyle class

Sets the style to customize the week number text of SfCalendar.

Allows to customize the backgroundColor, textStyle in week number of calendar.


Widget build(BuildContext context) {
   return Container(
     child: SfCalendar(
       view: CalendarView.month,
       showWeekNumber: true,
       weekNumberStyle: WeekNumberStyle(
           backgroundColor: Colors.blue,
           textStyle: TextStyle(color: Colors.grey, fontSize: 20),
     ),
   );
 }

Mixed-in types
Annotations

Constructors

WeekNumberStyle({Color? backgroundColor, TextStyle? textStyle})
Creates a week number style for calendar.
const

Properties

backgroundColor → Color?
The color that fills the background of the week number panel.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle?
The text style to customize week number text of the SfCalendar.
final

Methods

debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override