height property
Optional explicit height to use for each resource item.
When height is provided, value will be used as the per-resource height in scenarios where visibleResourceCount
is not provided. If visibleResourceCount is provided, it determines
the height distribution and height property will be ignored.
Example:
@override
Widget build(BuildContext context) {
return Container(
child: SfCalendar(
view: CalendarView.timelineMonth,
dataSource: _getCalendarDataSource(),
resourceViewSettings: ResourceViewSettings(
height: 120,
displayNameTextStyle: TextStyle(
fontStyle: FontStyle.italic,
fontSize: 15,
fontWeight: FontWeight.w400,
),
),
),
);
}
Implementation
final double? height;