width property
Optional explicit width to use for the resource panel.
When width is provided, value will be used as the resource panel width.
Example:
@override
Widget build(BuildContext context) {
return Container(
child: SfCalendar(
view: CalendarView.timelineMonth,
dataSource: _getCalendarDataSource(),
resourceViewSettings: ResourceViewSettings(
width: 150,
displayNameTextStyle: TextStyle(
fontStyle: FontStyle.italic,
fontSize: 15,
fontWeight: FontWeight.w400,
),
),
),
);
}
Implementation
final double? width;